@@ -23,9 +23,8 @@ describe('copy-sync / broken symlink', () => {
 
   afterEach(done => fse.remove(TEST_DIR, done))
 
-  it('should copy broken symlinks by default', () => {
-    assert.doesNotThrow(() => copySync(src, out))
-    assert.equal(fs.readlinkSync(path.join(out, 'broken-symlink')), path.join(src, 'does-not-exist'))
+  it('should error if symlink is broken', () => {
+    assert.throws(() => copySync(src, out))
   })
 
   it('should throw an error when dereference=true', () => {
