@@ -6,9 +6,9 @@ const path = require('path')
 const assert = require('assert')
 const crypto = require('crypto')
 
-/* global beforeEach, describe, it */
+/* global beforeEach, afterEach, describe, it */
 
-describe('+ copySync()', () => {
+describe('+ copySync() / dir', () => {
   const SIZE = 16 * 64 * 1024 + 7
   let TEST_DIR
   let src, dest
@@ -20,7 +20,9 @@ describe('+ copySync()', () => {
     fs.emptyDir(TEST_DIR, done)
   })
 
-  describe('> when the source is a directory', () => {
+  afterEach(done => fs.remove(TEST_DIR, done))
+
+  describe('> when src is a directory', () => {
     describe('> when dest exists and is a file', () => {
       it('should throw error', () => {
         const src = path.join(TEST_DIR, 'src')
@@ -70,13 +72,15 @@ describe('+ copySync()', () => {
     })
 
     it('should preserve symbolic links', () => {
+      const srcTarget = path.join(TEST_DIR, 'destination')
       fs.mkdirSync(src)
-      fs.symlinkSync('destination', path.join(src, 'symlink'))
+      fs.mkdirSync(srcTarget)
+      fs.symlinkSync(srcTarget, path.join(src, 'symlink'))
 
       fs.copySync(src, dest)
 
       const link = fs.readlinkSync(path.join(dest, 'symlink'))
-      assert.strictEqual(link, 'destination')
+      assert.strictEqual(link, srcTarget)
     })
 
     describe('> when the destination dir does not exist', () => {
@@ -183,14 +187,9 @@ describe('+ copySync()', () => {
       const dest = path.join(TEST_DIR, 'dest')
 
       setTimeout(() => {
-        fs.mkdirSync(src)
-        fs.writeFileSync(path.join(src, 'somefile.html'), 'some data')
+        fs.outputFileSync(path.join(src, 'somefile.html'), 'some data')
         fs.mkdirSync(dest)
-        try {
-          fs.copySync(src, dest, filter)
-        } catch (err) {
-          assert.ifError(err)
-        }
+        fs.copySync(src, dest, filter)
         assert(!fs.existsSync(path.join(dest, 'somefile.html')))
         done()
       }, 1000)
