@@ -10,17 +10,17 @@ const crypto = require('crypto')
 
 const SIZE = 16 * 64 * 1024 + 7
 
-describe('+ copySync()', () => {
+describe('+ copySync() / file', () => {
   let TEST_DIR
 
   beforeEach(done => {
-    TEST_DIR = path.join(os.tmpdir(), 'fs-extra', 'copy-sync')
+    TEST_DIR = path.join(os.tmpdir(), 'fs-extra', 'copy-sync-file')
     fs.emptyDir(TEST_DIR, done)
   })
 
   afterEach(done => fs.remove(TEST_DIR, done))
 
-  describe('> when the source is a file', () => {
+  describe('> when src is a file', () => {
     it('should copy the file synchronously', () => {
       const fileSrc = path.join(TEST_DIR, 'TEST_fs-extra_src')
       const fileDest = path.join(TEST_DIR, 'TEST_fs-extra_copy')
@@ -104,7 +104,7 @@ describe('+ copySync()', () => {
       })
     })
 
-    describe('> when the source file does not have write permissions', () => {
+    describe('> when src file does not have write permissions', () => {
       it('should be able to copy contents of file', () => {
         const fileSrc = path.join(TEST_DIR, 'file.txt')
         const fileDest = path.join(TEST_DIR, 'file-copy.txt')
