@@ -30,8 +30,8 @@ describe('copy-sync / symlink', () => {
       copySync(src, out)
     })
 
-    assert.equal(fs.readlinkSync(path.join(out, 'file-symlink')), path.join(src, 'foo'))
-    assert.equal(fs.readlinkSync(path.join(out, 'dir-symlink')), path.join(src, 'dir'))
+    assert.strictEqual(fs.readlinkSync(path.join(out, 'file-symlink')), path.join(src, 'foo'))
+    assert.strictEqual(fs.readlinkSync(path.join(out, 'dir-symlink')), path.join(src, 'dir'))
   })
 
   it('copies file contents when dereference=true', () => {
@@ -43,11 +43,11 @@ describe('copy-sync / symlink', () => {
 
     const fileSymlinkPath = path.join(out, 'file-symlink')
     assert.ok(fs.lstatSync(fileSymlinkPath).isFile())
-    assert.equal(fs.readFileSync(fileSymlinkPath), 'foo contents')
+    assert.strictEqual(fs.readFileSync(fileSymlinkPath, 'utf8'), 'foo contents')
 
     const dirSymlinkPath = path.join(out, 'dir-symlink')
     assert.ok(fs.lstatSync(dirSymlinkPath).isDirectory())
-    assert.deepEqual(fs.readdirSync(dirSymlinkPath), ['bar'])
+    assert.deepStrictEqual(fs.readdirSync(dirSymlinkPath), ['bar'])
   })
 })
 
