@@ -9,7 +9,7 @@ const assert = require('assert')
 
 /* global afterEach, beforeEach, describe, it */
 
-describe('ncp broken symlink', function () {
+describe('ncp broken symlink', () => {
   const TEST_DIR = path.join(os.tmpdir(), 'fs-extra', 'ncp-broken-symlinks')
   const src = path.join(TEST_DIR, 'src')
   const out = path.join(TEST_DIR, 'out')
@@ -23,17 +23,16 @@ describe('ncp broken symlink', function () {
 
   afterEach(done => fse.remove(TEST_DIR, done))
 
-  it('should copy broken symlinks by default', done => {
+  it('should error if symlink is broken', done => {
     ncp(src, out, err => {
-      if (err) return done(err)
-      assert.equal(fs.readlinkSync(path.join(out, 'broken-symlink')), path.join(src, 'does-not-exist'))
+      assert(err)
       done()
     })
   })
 
   it('should return an error when dereference=true', done => {
     ncp(src, out, {dereference: true}, err => {
-      assert.equal(err.code, 'ENOENT')
+      assert.strictEqual(err.code, 'ENOENT')
       done()
     })
   })
