@@ -24,7 +24,7 @@ describe('ncp', () => {
         readDirFiles(src, 'utf8', (srcErr, srcFiles) => {
           readDirFiles(out, 'utf8', (outErr, outFiles) => {
             assert.ifError(srcErr)
-            assert.deepEqual(srcFiles, outFiles)
+            assert.deepStrictEqual(srcFiles, outFiles)
             cb()
           })
         })
@@ -41,7 +41,7 @@ describe('ncp', () => {
       it('files are copied correctly', cb => {
         readDirFiles(src, 'utf8', (srcErr, srcFiles) => {
           function filter (files) {
-            for (let fileName in files) {
+            for (const fileName in files) {
               const curFile = files[fileName]
               if (curFile instanceof Object) {
                 return filter(curFile)
@@ -55,7 +55,7 @@ describe('ncp', () => {
           filter(srcFiles)
           readDirFiles(out, 'utf8', (outErr, outFiles) => {
             assert.ifError(outErr)
-            assert.deepEqual(srcFiles, outFiles)
+            assert.deepStrictEqual(srcFiles, outFiles)
             cb()
           })
         })
@@ -133,7 +133,7 @@ describe('ncp', () => {
       it('file descriptors are passed correctly', cb => {
         ncp(src, out, {
           transform: (read, write, file) => {
-            assert.notEqual(file.name, undefined)
+            assert.notStrictEqual(file.name, undefined)
             assert.strictEqual(typeof file.mode, 'number')
             read.pipe(write)
           }
@@ -143,7 +143,7 @@ describe('ncp', () => {
   })
 
   // see https://github.com/AvianFlu/ncp/issues/71
-  describe('Issue 71: Odd Async Behaviors', cb => {
+  describe('Issue 71: Odd Async Behaviors', () => {
     const fixtures = path.join(__dirname, 'fixtures', 'regular-fixtures')
     const src = path.join(fixtures, 'src')
     const out = path.join(fixtures, 'out')
@@ -158,7 +158,7 @@ describe('ncp', () => {
         readDirFiles(src, 'utf8', (srcErr, srcFiles) => {
           readDirFiles(out, 'utf8', (outErr, outFiles) => {
             assert.ifError(srcErr)
-            assert.deepEqual(srcFiles, outFiles)
+            assert.deepStrictEqual(srcFiles, outFiles)
             callback()
           })
         })
@@ -181,7 +181,7 @@ describe('ncp', () => {
             }, 100)
           } else {
             // console.log('Total callback count is', totalCallbacks)
-            assert.equal(totalCallbacks, expected)
+            assert.strictEqual(totalCallbacks, expected)
             done()
           }
         }
