@@ -38,7 +38,7 @@ describe('fs-extra', () => {
         fs.writeFileSync(file, 'hello world')
         fse.createFile(file, err => {
           assert.ifError(err)
-          assert.equal(fs.readFileSync(file, 'utf8'), 'hello world')
+          assert.strictEqual(fs.readFileSync(file, 'utf8'), 'hello world')
           done()
         })
       })
@@ -61,7 +61,7 @@ describe('fs-extra', () => {
         fse.mkdirsSync(path.dirname(file))
         fs.writeFileSync(file, 'hello world')
         fse.createFileSync(file)
-        assert.equal(fs.readFileSync(file, 'utf8'), 'hello world')
+        assert.strictEqual(fs.readFileSync(file, 'utf8'), 'hello world')
       })
     })
   })
