@@ -53,7 +53,7 @@ describe('fs-extra', () => {
 
         fse.ensureFile(p, err => {
           assert(err)
-          assert.equal(err.code, 'EISDIR')
+          assert.strictEqual(err.code, 'EISDIR')
           done()
         })
       })
@@ -91,7 +91,7 @@ describe('fs-extra', () => {
           try {
             fse.ensureFileSync(p)
           } catch (e) {
-            assert.equal(e.code, 'EISDIR')
+            assert.strictEqual(e.code, 'EISDIR')
             throw e
           }
         })
