@@ -98,11 +98,11 @@ describe('symlink-type', () => {
       it(`should return '${expectedType}' when src '${args[0]}'`, done => {
         const callback = (err, type) => {
           if (err) done(err)
-          assert.equal(type, expectedType)
+          assert.strictEqual(type, expectedType)
           done()
         }
         args.push(callback)
-        return symlinkType.apply(null, args)
+        return symlinkType(...args)
       })
     })
   })
@@ -112,8 +112,8 @@ describe('symlink-type', () => {
       const args = test[0]
       const expectedType = test[1]
       it(`should return '${expectedType}' when src '${args[0]}'`, () => {
-        const type = symlinkTypeSync.apply(null, args)
-        assert.equal(type, expectedType)
+        const type = symlinkTypeSync(...args)
+        assert.strictEqual(type, expectedType)
       })
     })
   })
