@@ -26,7 +26,7 @@ if (typeof fs.copyFile === 'function') {
       fse.writeFileSync(src, 'hello')
       return fse.copyFile(src, dest).then(() => {
         const data = fse.readFileSync(dest, 'utf8')
-        assert.equal(data, 'hello')
+        assert.strictEqual(data, 'hello')
       })
     })
   })
