@@ -22,13 +22,13 @@ describe('native fs', () => {
     const file = path.join(TEST_DIR, 'write.txt')
     fse.writeFileSync(file, 'hello')
     const data = fse.readFileSync(file, 'utf8')
-    assert.equal(data, 'hello')
+    assert.strictEqual(data, 'hello')
   })
 
   it('should have native fs constants', () => {
     // Node.js v0.12 / IO.js
     if ('F_OK' in fs) {
-      assert.equal(fse.F_OK, fs.F_OK)
+      assert.strictEqual(fse.F_OK, fs.F_OK)
     }
   })
 })
