@@ -13,7 +13,7 @@ describe('json', () => {
   let TEST_DIR
 
   beforeEach(done => {
-    TEST_DIR = path.join(os.tmpdir(), 'fs-extra')
+    TEST_DIR = path.join(os.tmpdir(), 'fs-extra-output-json')
     fse.emptyDir(TEST_DIR, done)
   })
 
@@ -29,7 +29,7 @@ describe('json', () => {
         assert(fs.existsSync(file))
         const newData = JSON.parse(fs.readFileSync(file, 'utf8'))
 
-        assert.equal(data.name, newData.name)
+        assert.strictEqual(data.name, newData.name)
         done()
       })
     })
@@ -53,7 +53,7 @@ describe('json', () => {
         outputJson(file, data, { replacer }, err => {
           assert.ifError(err)
           const newData = JSON.parse(fs.readFileSync(file, 'utf8'))
-          assert.equal(newData.name, 'Jon Paul')
+          assert.strictEqual(newData.name, 'Jon Paul')
           done()
         })
       })
