@@ -45,9 +45,9 @@ describe('mkdirp / clobber', () => {
     fse.mkdirp(file, o755, err => {
       assert.ok(err)
       if (os.platform().indexOf('win') === 0) {
-        assert.equal(err.code, 'EEXIST')
+        assert.strictEqual(err.code, 'EEXIST')
       } else {
-        assert.equal(err.code, 'ENOTDIR')
+        assert.strictEqual(err.code, 'ENOTDIR')
       }
       done()
     })
