@@ -1,20 +1,22 @@
-var assert = require('assert')
-var fse = require(process.cwd())
+'use strict'
+
+const assert = require('assert')
+const fse = require(process.cwd())
 
 /* global describe, it */
 
-describe('mkdirp: issue-209, win32, when bad path, should return a cleaner error', function () {
+describe('mkdirp: issue-209, win32, when bad path, should return a cleaner error', () => {
   // only seems to be an issue on Windows.
   if (process.platform !== 'win32') return
 
-  it('should return a callback', function (done) {
-    var file = './bad?dir'
-    fse.mkdirp(file, function (err) {
+  it('should return a callback', done => {
+    const file = './bad?dir'
+    fse.mkdirp(file, err => {
       assert(err, 'error is present')
       assert.strictEqual(err.code, 'EINVAL')
 
-      var file2 = 'c:\\tmp\foo:moo'
-      fse.mkdirp(file2, function (err) {
+      const file2 = 'c:\\tmp\foo:moo'
+      fse.mkdirp(file2, err => {
         assert(err, 'error is present')
         assert.strictEqual(err.code, 'EINVAL')
         done()
@@ -22,11 +24,11 @@ describe('mkdirp: issue-209, win32, when bad path, should return a cleaner error
     })
   })
 
-  describe('> sync', function () {
-    it('should throw an error', function () {
-      var didErr
+  describe('> sync', () => {
+    it('should throw an error', () => {
+      let didErr
       try {
-        var file = 'c:\\tmp\foo:moo'
+        const file = 'c:\\tmp\foo:moo'
         fse.mkdirpSync(file)
       } catch (err) {
         // console.error(err)
