@@ -23,7 +23,7 @@ describe('mkdirp / perm', () => {
   afterEach(done => fse.remove(TEST_DIR, done))
 
   it('async perm', done => {
-    let file = path.join(TEST_DIR, (Math.random() * (1 << 30)).toString(16))
+    const file = path.join(TEST_DIR, (Math.random() * (1 << 30)).toString(16))
 
     fse.mkdirp(file, o755, err => {
       assert.ifError(err)
@@ -34,9 +34,9 @@ describe('mkdirp / perm', () => {
           assert.ifError(err)
 
           if (os.platform().indexOf('win') === 0) {
-            assert.equal(stat.mode & o777, o666)
+            assert.strictEqual(stat.mode & o777, o666)
           } else {
-            assert.equal(stat.mode & o777, o755)
+            assert.strictEqual(stat.mode & o777, o755)
           }
 
           assert.ok(stat.isDirectory(), 'target not a directory')
