@@ -30,10 +30,10 @@ describe('mkdirp / return value', () => {
     // already exist, since every other test makes things in there.
     // Note that this will throw on failure, which will fail the test.
     let made = fse.mkdirpSync(file)
-    assert.equal(made, dir + x)
+    assert.strictEqual(made, dir + x)
 
     // making the same file again should have no effect.
     made = fse.mkdirpSync(file)
-    assert.equal(made, null)
+    assert.strictEqual(made, null)
   })
 })
