@@ -26,7 +26,7 @@ describe('output', () => {
         fse.outputFile(file, 'hi jp', err => {
           assert.ifError(err)
           assert(fs.existsSync(file))
-          assert.equal(fs.readFileSync(file, 'utf8'), 'hi jp')
+          assert.strictEqual(fs.readFileSync(file, 'utf8'), 'hi jp')
           done()
         })
       })
@@ -44,7 +44,7 @@ describe('output', () => {
         fs.writeFileSync(file, 'hello world')
         fse.outputFile(file, 'hello jp', err => {
           if (err) return done(err)
-          assert.equal(fs.readFileSync(file, 'utf8'), 'hello jp')
+          assert.strictEqual(fs.readFileSync(file, 'utf8'), 'hello jp')
           done()
         })
       })
@@ -58,7 +58,7 @@ describe('output', () => {
         assert(!fs.existsSync(file))
         fse.outputFileSync(file, 'hello man')
         assert(fs.existsSync(file))
-        assert.equal(fs.readFileSync(file, 'utf8'), 'hello man')
+        assert.strictEqual(fs.readFileSync(file, 'utf8'), 'hello man')
       })
     })
 
@@ -68,7 +68,7 @@ describe('output', () => {
         fse.mkdirsSync(path.dirname(file))
         fs.writeFileSync(file, 'hello world')
         fse.outputFileSync(file, 'hello man')
-        assert.equal(fs.readFileSync(file, 'utf8'), 'hello man')
+        assert.strictEqual(fs.readFileSync(file, 'utf8'), 'hello man')
       })
     })
   })
