@@ -25,17 +25,17 @@ describe('utimes', () => {
   describe('hasMillisResSync()', () => {
     it('should return a boolean indicating whether it has support', () => {
       const res = utimes.hasMillisResSync()
-      assert.equal(typeof res, 'boolean')
+      assert.strictEqual(typeof res, 'boolean')
 
       // HFS => false
-      if (process.platform === 'darwin') assert.equal(res, false)
+      if (process.platform === 'darwin') assert.strictEqual(res, false)
 
       // does anyone use FAT anymore?
-      // if (process.platform === 'win32') assert.equal(res, true)
+      // if (process.platform === 'win32') assert.strictEqual(res, true)
       // fails on appveyor... could appveyor be using FAT?
 
       // this would fail if ext2/ext3
-      if (process.platform === 'linux') assert.equal(res, true)
+      if (process.platform === 'linux') assert.strictEqual(res, true)
     })
   })
 
@@ -60,18 +60,18 @@ describe('utimes', () => {
       const awhileAgo = new Date(1334990868773)
       const awhileAgoNoMillis = new Date(1334990868000)
 
-      assert.notDeepEqual(stats.mtime, awhileAgo)
-      assert.notDeepEqual(stats.atime, awhileAgo)
+      assert.notDeepStrictEqual(stats.mtime, awhileAgo)
+      assert.notDeepStrictEqual(stats.atime, awhileAgo)
 
       utimes.utimesMillis(tmpFile, awhileAgo, awhileAgo, err => {
         assert.ifError(err)
         stats = fs.statSync(tmpFile)
         if (utimes.hasMillisResSync()) {
-          assert.deepEqual(stats.mtime, awhileAgo)
-          assert.deepEqual(stats.atime, awhileAgo)
+          assert.deepStrictEqual(stats.mtime, awhileAgo)
+          assert.deepStrictEqual(stats.atime, awhileAgo)
         } else {
-          assert.deepEqual(stats.mtime, awhileAgoNoMillis)
-          assert.deepEqual(stats.atime, awhileAgoNoMillis)
+          assert.deepStrictEqual(stats.mtime, awhileAgoNoMillis)
+          assert.deepStrictEqual(stats.atime, awhileAgoNoMillis)
         }
         done()
       })
@@ -87,7 +87,7 @@ describe('utimes', () => {
 
       let closeCalled = false
       gracefulFsStub.close = (fd, callback) => {
-        assert.equal(fd, fakeFd)
+        assert.strictEqual(fd, fakeFd)
         closeCalled = true
         if (callback) process.nextTick(callback)
       }
@@ -101,7 +101,7 @@ describe('utimes', () => {
       }
 
       utimes.utimesMillis('ignored', 'ignored', 'ignored', err => {
-        assert.equal(err, testError)
+        assert.strictEqual(err, testError)
         assert(closeCalled)
         done()
       })
